@@ -11,6 +11,9 @@ from pathlib import  Path
 
 class sound_manager:
     __font = cv2.FONT_HERSHEY_COMPLEX_SMALL
+    SENSITIVITY_LOW = 8
+    SENSITIVITY_MEDIUM = 3
+    SENSITIVITY_HIGH = 1
 
     def __init__(self,audio):
         mixer.init()
@@ -20,8 +23,13 @@ class sound_manager:
             self.__sound = mixer.Sound(audio)
         self.__timer = None # used to play audio after certain time
         self.__lastState = None # used to filter out the events
+        self.__sensitivity = self.__class__.SENSITIVITY_HIGH
 
 
+    def setSensitivity(self,sensitivity):
+        if isinstance(sensitivity,int):
+            self.__sensitivity = sensitivity
+
 
 
     def handle_sound(self,open_eyes):
@@ -44,7 +52,7 @@ class sound_manager:
               # then timer will be revoked by upper if condition
               # else it will play sound after that time interval
               print("drowsy chances")
-              self.__timer = Timer(1,function=self.handle_delayed)
+              self.__timer = Timer(self.__sensitivity,function=self.handle_delayed)
               self.__timer.start()
 
 
